@@ -1,3 +1,7 @@
 from IgoTokenizer import IgoTokenizer
 from TinySegmenterTokenizer import TinySegmenterTokenizer
-from MeCabTokenizer import MeCabTokenizer
+try:
+    from MeCabTokenizer import MeCabTokenizer
+except:
+    pass
+
